window.Gleam.initSearch([{"doc":"comet","title":"comet","content":"# comet\n\n[![Package Version](https://img.shields.io/hexpm/v/comet)](https://hex.pm/packages/comet)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/comet/)\n\n```sh\ngleam add comet\n```\n```gleam\nimport comet.{Debug, Info, Warn, Error as Err, String, Int}\n\npub fn main() {\n  let log = comet.builder()\n  |&gt; comet.timestamp\n  |&gt; comet.attributes([String(&quot;service&quot;, &quot;comet&quot;)])\n  |&gt; comet.log_level(Info)\n  |&gt; comet.logger\n\n  log(Info, &quot;application starting...&quot;, [String(&quot;fn&quot;, &quot;main&quot;), Int(&quot;process&quot;, 1)])\n}\n```\n\noutputs the log\n```\n{&quot;level&quot;:&quot;info&quot;,&quot;timestamp&quot;:&quot;2024-04-23T06:33:59.101Z&quot;,&quot;service&quot;:&quot;comet&quot;,&quot;fn&quot;:&quot;main&quot;,&quot;process&quot;:1,&quot;msg&quot;:&quot;application starting...&quot;}\n```\n\nAdditionally, level specific log functions can be created:\n\n```gleam\n  let assert comet.LevelLoggerSet(trace, debug, info, warn, err) =\n    comet.builder()\n    |&gt; comet.timestamp\n    |&gt; comet.attributes([comet.String(&quot;service&quot;, &quot;comet&quot;)])\n    |&gt; comet.log_level(Info)\n    |&gt; comet.logger\n    |&gt; comet.levels\n  debug(&quot;log settings&quot;, [String(&quot;min_log_level&quot;, &quot;info&quot;)])\n  info(&quot;✨ application starting...&quot;, [String(&quot;fn&quot;, &quot;main&quot;), Int(&quot;process&quot;, 1)])\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/comet&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"comet","title":"Attribute","content":"pub type Attribute {\n  String(key: String, value: String)\n  Int(key: String, value: Int)\n  Float(key: String, value: Float)\n  Bool(key: String, value: Bool)\n  Fn(fn() -&gt; Attribute)\n}\n\nString(key: String, value: String)\n\n\nInt(key: String, value: Int)\n\n\nFloat(key: String, value: Float)\n\n\nBool(key: String, value: Bool)\n\n\nFn(fn() -&gt; Attribute)\n\n\nSynonyms:\ncomet.Attribute\ncomet Attribute","url":"comet.html#Attribute"},{"doc":"comet","title":"Context","content":"pub opaque type Context\n\n\nSynonyms:\ncomet.Context\ncomet Context","url":"comet.html#Context"},{"doc":"comet","title":"Entry","content":"pub type Entry {\n  Entry(\n    ctx: Context,\n    level: Level,\n    message: String,\n    attributes: List(Attribute),\n  )\n}\n\nEntry(\n  ctx: Context,\n  level: Level,\n  message: String,\n  attributes: List(Attribute),\n)\n\n\nSynonyms:\ncomet.Entry\ncomet Entry","url":"comet.html#Entry"},{"doc":"comet","title":"Formatter","content":"pub type Formatter =\n  fn(Level, String, List(Attribute)) -&gt; String\n\n\nSynonyms:\ncomet.Formatter\ncomet Formatter","url":"comet.html#Formatter"},{"doc":"comet","title":"Level","content":"pub type Level {\n  Trace\n  Debug\n  Info\n  Warn\n  Error\n  Panic\n}\n\nTrace\n\n\nDebug\n\n\nInfo\n\n\nWarn\n\n\nError\n\n\nPanic\n\n\nSynonyms:\ncomet.Level\ncomet Level","url":"comet.html#Level"},{"doc":"comet","title":"LevelLoggerSet","content":"pub type LevelLoggerSet {\n  LevelLoggerSet(\n    trace: LevelLogger,\n    debug: LevelLogger,\n    info: LevelLogger,\n    warn: LevelLogger,\n    error: LevelLogger,\n  )\n}\n\nLevelLoggerSet(\n  trace: LevelLogger,\n  debug: LevelLogger,\n  info: LevelLogger,\n  warn: LevelLogger,\n  error: LevelLogger,\n)\n\n\nSynonyms:\ncomet.LevelLoggerSet\ncomet LevelLoggerSet","url":"comet.html#LevelLoggerSet"},{"doc":"comet","title":"LevelTextFn","content":"pub type LevelTextFn =\n  fn(Level) -&gt; String\n\n\nSynonyms:\ncomet.LevelTextFn\ncomet LevelTextFn","url":"comet.html#LevelTextFn"},{"doc":"comet","title":"Output","content":"pub type Output =\n  fn(String, Level) -&gt; Nil\n\n\nSynonyms:\ncomet.Output\ncomet Output","url":"comet.html#Output"},{"doc":"comet","title":"attributes","content":"pub fn attributes(\n  next: fn(Entry) -&gt; Option(Entry),\n  attributes: List(Attribute),\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.attributes\ncomet attributes","url":"comet.html#attributes"},{"doc":"comet","title":"builder","content":"pub fn builder() -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.builder\ncomet builder","url":"comet.html#builder"},{"doc":"comet","title":"debug","content":"pub fn debug(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; fn(String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.debug\ncomet debug","url":"comet.html#debug"},{"doc":"comet","title":"error","content":"pub fn error(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; fn(String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.error\ncomet error","url":"comet.html#error"},{"doc":"comet","title":"formatter","content":"pub fn formatter(\n  next: fn(Entry) -&gt; Option(Entry),\n  formatter: fn(Level, String, List(Attribute)) -&gt; String,\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.formatter\ncomet formatter","url":"comet.html#formatter"},{"doc":"comet","title":"get_level_text","content":"pub fn get_level_text(level: Level) -&gt; String\n\nSynonyms:\ncomet.get_level_text\ncomet get_level_text","url":"comet.html#get_level_text"},{"doc":"comet","title":"info","content":"pub fn info(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; fn(String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.info\ncomet info","url":"comet.html#info"},{"doc":"comet","title":"json_formatter","content":"pub fn json_formatter(\n  level: Level,\n  msg: String,\n  attributes: List(Attribute),\n) -&gt; String\n\nSynonyms:\ncomet.json_formatter\ncomet json_formatter","url":"comet.html#json_formatter"},{"doc":"comet","title":"level_priority","content":"pub fn level_priority(level: Level) -&gt; Int\n\nSynonyms:\ncomet.level_priority\ncomet level_priority","url":"comet.html#level_priority"},{"doc":"comet","title":"level_text","content":"pub fn level_text(\n  next: fn(Entry) -&gt; Option(Entry),\n  func: fn(Level) -&gt; String,\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.level_text\ncomet level_text","url":"comet.html#level_text"},{"doc":"comet","title":"levels","content":"pub fn levels(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; LevelLoggerSet\n\nSynonyms:\ncomet.levels\ncomet levels","url":"comet.html#levels"},{"doc":"comet","title":"log_level","content":"pub fn log_level(\n  next: fn(Entry) -&gt; Option(Entry),\n  level: Level,\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.log_level\ncomet log_level","url":"comet.html#log_level"},{"doc":"comet","title":"logger","content":"pub fn logger(\n  next: fn(Entry) -&gt; Option(Entry),\n) -&gt; fn(Level, String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.logger\ncomet logger","url":"comet.html#logger"},{"doc":"comet","title":"output","content":"pub fn output(\n  next: fn(Entry) -&gt; Option(Entry),\n  output: fn(String, Level) -&gt; Nil,\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.output\ncomet output","url":"comet.html#output"},{"doc":"comet","title":"timestamp","content":"pub fn timestamp(\n  next: fn(Entry) -&gt; Option(Entry),\n) -&gt; fn(Entry) -&gt; Option(Entry)\n\nSynonyms:\ncomet.timestamp\ncomet timestamp","url":"comet.html#timestamp"},{"doc":"comet","title":"trace","content":"pub fn trace(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; fn(String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.trace\ncomet trace","url":"comet.html#trace"},{"doc":"comet","title":"warn","content":"pub fn warn(\n  log: fn(Level, String, List(Attribute)) -&gt; Nil,\n) -&gt; fn(String, List(Attribute)) -&gt; Nil\n\nSynonyms:\ncomet.warn\ncomet warn","url":"comet.html#warn"},{"doc":"comet","title":"write_output","content":"pub fn write_output(entry: String, level: Level) -&gt; Nil\n\nSynonyms:\ncomet.write_output\ncomet write_output","url":"comet.html#write_output"},{"doc":"comet","title":"comet","content":" Create a gleaming trail of application logs. ","url":"comet.html"}]);